@@ -205,6 +205,10 @@ def get_history(customer_name, date):
             ).format(name=customer_name, date=date)
             rows = db.query(sql)
             fup_history = rows.as_dict()
+        LOGS.logger.info(
+            "Customer {} fup history for {}: {}"
+            .format(customer_name, date, fup_history)
+        )
         return fup_history[0]
     except Exception as e:
         operation = (
